%bcond_with test
%bcond_with bench
%bcond_with backup
%bcond_with wsrep
%bcond_with devel
%bcond_with debug
%bcond_with db2iengine
%define db2iversion 1.1.5

Name: mariadb
Version: 10.3.32
Release: 4
# https://github.com/MariaDB/server/tree/10.3#licensing
License: GPL-2.0-only
Summary: Open Source Drop-in replacement for MySQL
Url: https://mariadb.org/

Source0: https://archive.mariadb.org/mariadb-%{version}/source/mariadb-%{version}.tar.gz
%if %{with db2iengine}
Source1: https://github.com/zendtech/db2iengine/releases/download/v%{db2iversion}/db2iengine-%{db2iversion}.tar.gz
%endif
Patch3: mariadb-openat.patch
Patch4: mariadb-o_nofollow-and-o_cloexec.patch
Patch5: mariadb-dbug.patch
Patch6: mariadb-disable-large-files.patch
Patch7: mariadb-disable-clockgettime.patch
Patch9: mariadb-threadpool.patch
Patch10: mariadb-posix-fadvise.patch
Patch11: mariadb-skip-relro-now-check.patch
Patch12: mariadb-link-plugins.patch
# This patch can be dropped in 10.5+
Patch13: mariadb-rm-my_ulonglong2double.patch

BuildRequires: bison
BuildRequires: cmake >= 3.16.0
BuildRequires: libevent-devel
BuildRequires: zlib-devel
BuildRequires: libncurses6
BuildRequires: openssl-devel >= 1.1.1
BuildRequires: openssl >= 1.1.1
BuildRequires: libutil-devel >= 0.8.0
BuildRequires: libxml2-devel
BuildRequires: groff
BuildRequires: pkg-config
BuildRequires: readline-devel
BuildRequires: pcre-devel
BuildRequires: libiconv-devel

Requires: libutil2 >= 0.8.1

%description
MariaDB is an enhanced, drop-in replacement for MySQL. MariaDB is used because
it is fast, scalable and robust, with a rich ecosystem of storage engines,
plugins and many other tools make it very versatile for a wide variety of 
use cases.

%package server
Summary: The MariaDB server and related files
Requires: %{name} = %{version}-%{release}

%description server
MariaDB is a multi-user, multi-threaded SQL database server. It is a
client/server implementation consisting of a server daemon (mysqld)
and many different client programs and libraries. This package contains
the MariaDB server and some accompanying files and directories.
MariaDB is a community developed branch of MySQL.

%if %{with devel}
%package  devel
Summary: Files for development of MariaDB/MySQL applications

Requires: mariadb-server = %{version}-%{release}

%description devel
MariaDB is a multi-user, multi-threaded SQL database server.
MariaDB is a community developed branch of MySQL.

This package contains everything needed for developing MariaDB/MySQL client
and server applications.
%endif

%if %{with backup}
%package backup
Summary: The mariabackup tool for physical online backups

Requires: mariadb-server = %{version}-%{release}

%description backup
MariaDB Backup is an open source tool provided by MariaDB for performing
physical online backups of InnoDB, Aria and MyISAM tables.
For InnoDB, "hot online" backups are possible.
%endif

%if %{with test}
%package test
Summary: The test suite distributed with MariaDB

Requires: mariadb-server = %{version}-%{release}

%description test
This package contains the regression test suite distributed with the MariaDB
sources.
%endif

%if %{with bench}
%package bench
Summary: MariaDB benchmark scripts and data

Requires: mariadb-server = %{version}-%{release}

%description bench
This package contains benchmark scripts and data for use when benchmarking
MariaDB.
%endif

%if %{with db2iengine}
%package db2iengine
Summary: Db2 for i Storage Engine

Requires: mariadb-server = %{version}-%{release}

%description db2iengine
Db2 for i Storage Engine
%endif

%prep
%setup -q

%if %{with db2iengine}
# unpack db2iengine and move it to the storage directory
tar -xf %SOURCE1
mv db2iengine-%{db2iversion} storage/ibmdb2i
%endif

%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1

# cleanup to use proper binaries
find . -type f | xargs perl -p -i -e 's|/usr/bin/perl|%{_bindir}/perl|g;s|#!/bin/sh|#!/QOpenSys/usr/bin/sh|g'

# remove unkown option from test cases --skip-stack-trace
find mysql-test -type f | xargs perl -p -i -e 's|--skip-stack-trace||g'

# generic build instructions https://mariadb.com/kb/en/library/generic-build-instructions/
%build

export LDFLAGS="-pthread -lutil -liconv -Wl,-brtl -Wl,-bbigtoc -Wl,-blibpath:/QOpenSys/pkgs/lib:/QOpenSys/usr/lib"

# -Wno-attributes added to ignore `warning: visibility attribute not supported in this configuration; ignored [-Wattributes]`
# -DHAVE_INT_8_16_32 is used to avoid redeclaring those inttypes
# -DCMAKE_POLICY_DEFAULT_CMP0065=NEW disables passing -bexpall to CMAKE_SHARED_LIBRARY_LINK_${lang}_FLAGS
cmake . \
    -LAH \
    -DCMAKE_POLICY_DEFAULT_CMP0065=NEW \
    -DCMAKE_INSTALL_PREFIX="%{_prefix}" \
    -DCMAKE_BUILD_TYPE=%{?with_debug:Debug}%{!?with_debug:RelWithDebInfo} \
    -DCMAKE_C_FLAGS="${CFLAGS:--maix64 -pthread -Wno-attributes -DHAVE_INT_8_16_32 -I/QOpenSys/pkgs/include/libiconv}" \
    -DCMAKE_C_FLAGS_RELWITHDEBINFO="-O2 -g" \
    -DCMAKE_C_FLAGS_DEBUG="-ggdb" \
    -DCMAKE_CXX_FLAGS="${CXXFLAGS:--maix64 -pthread -Wno-attributes -DHAVE_INT_8_16_32 -I/QOpenSys/pkgs/include/libiconv}" \
    -DCMAKE_CXX_FLAGS_RELWITHDEBINFO="-O2 -g" \
    -DCMAKE_CXX_FLAGS_DEBUG="-ggdb" \
    -DCMAKE_CXX_COMPILER="%{_bindir}/g++" \
    -DCMAKE_SYSTEM_PREFIX_PATH='/QOpenSys/pkgs;/QOpenSys/usr' \
    -DINSTALL_LIBDIR="%{_libdir}" \
    -DINSTALL_INCLUDEDIR="include/%{name}" \
    -DINSTALL_SYSCONFDIR="%{_sysconfdir}/%{name}" \
    -DINSTALL_SYSCONF2DIR="%{_sysconfdir}/%{name}" \
    -DINSTALL_INFODIR="%{_infodir}" \
    -DINSTALL_DOCDIR="%{_datadir}/doc/%{name}" \
    -DINSTALL_DOCREADMEDIR="%{_datadir}/doc/%{name}" \
    -DINSTALL_BINDIR="%{_bindir}" \
    -DINSTALL_SBINDIR="%{_bindir}" \
    -DINSTALL_MANDIR="%{_mandir}" \
    -DINSTALL_PLUGINDIR="lib/%{name}/plugin" \
    -DINSTALL_MYSQLSHAREDIR="%{_datadir}/%{name}" \
    -DINSTALL_MYSQLTESTDIR=%{?with_test:share/mysql-test}%{!?with_test:} \
    -DINSTALL_SQLBENCHDIR="%{_datadir}" \
    -DINSTALL_SHAREDIR="%{_datadir}" \
    -DINSTALL_SCRIPTDIR="%{_bindir}" \
    -DINSTALL_SUPPORTFILESDIR="%{_datadir}/%{name}" \
    -DINSTALL_MYSQLDATADIR="%{_localstatedir}/lib/%{name}/data" \
    -DINSTALL_UNIX_ADDRDIR=%{_localstatedir}/lib/mysql/mysql.sock \
    -DINSTALL_LAYOUT="RPM" \
    -DMYSQL_DATADIR="%{_localstatedir}/lib/%{name}/data" \
    -DICONV_INCLUDE_DIR="%{_includedir}" \
    -DDEFAULT_CHARSET=utf8mb4 \
    -DDEFAULT_COLLATION=utf8mb4_general_ci \
    -DWITH_ZLIB=system \
    -DWITH_LIBEVENT=system \
    -DWITH_READLINE=system \
    -DWITH_PCRE=system \
    -DWITH_JEMALLOC=no \
    -DCONC_WITH_SSL=ON \
    -DWITH_SSL=system \
    -DWITH_SYSTEMD=no \
    -DWITH_WSREP=%{?with_wsrep:YES}%{!?with_wsrep:NO} \
    -DWITH_MARIABACKUP=%{?with_backup:ON}%{!?with_backup:NO} \
    -DWITHOUT_MROONGA=1 \
    -DWITH_UNIT_TESTS=NO \
    -DPLUGIN_ARIA=STATIC \
    -DPLUGIN_ARCHIVE=STATIC \
    -DPLUGIN_AUTH_ED25519=NO \
    -DPLUGIN_CLIENT_ED25519=OFF \
    -DPLUGIN_AUTH_PAM=NO \
    -DPLUGIN_AWS_KEY_MANAGEMENT=NO \
    -DPLUGIN_BLACKHOLE=NO \
    -DPLUGIN_CONNECT=NO \
    -DPLUGIN_DAEMON_EXAMPLE=NO \
    -DPLUGIN_DEBUG_KEY_MANAGEMENT=NO \
    -DPLUGIN_DIALOG_EXAMPLES=NO \
    -DPLUGIN_EXAMPLE=NO \
    -DPLUGIN_EXAMPLE_KEY_MANAGEMENT=NO \
    -DPLUGIN_FEDERATEDX=NO \
    -DPLUGIN_FEDERATED=NO \
    -DPLUGIN_FEEDBACK=NO \
    -DPLUGIN_FILE_KEY_MANAGEMENT=NO \
    -DPLUGIN_FTEXAMPLE=NO \
    -DPLUGIN_HANDLERSOCKET=NO \
    -DPLUGIN_IBMDB2I=DYNAMIC \
    -DPLUGIN_INNOBASE=STATIC \
    -DPLUGIN_PARTITION=STATIC \
    -DPLUGIN_PERFSCHEMA=STATIC \
    -DPLUGIN_QUERY_RESPONSE_TIME=NO \
    -DPLUGIN_SEQUENCE=STATIC \
    -DPLUGIN_SERVER_AUDIT=STATIC \
    -DPLUGIN_SIMPLE_PASSWORD_CHECK=STATIC \
    -DPLUGIN_SPHINX=NO \
    -DPLUGIN_SPIDER=NO \
    -DPLUGIN_SQL_ERRLOG=NO \
    -DPLUGIN_USER_VARIABLES=NO \
    -DPLUGIN_WSREP_INFO=%{?with_wsrep:DYNAMIC}%{!?with_wsrep:NO} \
    -DHAVE_POSIX_FALLOCATE=0 \
    -DHAVE_CLOCK_GETTIME=0 \
    -DHAVE_MMAP64=0 \
    # end

%if %{with debug}
# hack -- removes all -Werror that get appended to c/cxx flags when making a debug build
find . -name flags.make | xargs perl -p -i -e 's|-Werror||g'
%endif

VERBOSE=1 %make_build

%check
#cd mysql-test
#./mysql-test-run.pl \
#    --skip-test-list=unstable-tests \
#    --skip-test=encryption \
#    --force
#    --max-test-fail=0

%install
%make_install

# when not building with devel sub-package
%if ! %{with devel}
rm -r %{buildroot}%{_includedir}/%{name}/*
rm %{buildroot}%{_libdir}/libmariadb.so
# latest CMake now generates versioned .so as well
rm %{buildroot}%{_libdir}/libmariadb.so.3
rm %{buildroot}%{_libdir}/libmariadbclient.a
rm %{buildroot}%{_libdir}/libmysqlclient.a
rm %{buildroot}%{_libdir}/libmysqlclient.so
rm %{buildroot}%{_libdir}/libmysqlclient_r.a
rm %{buildroot}%{_libdir}/libmysqlclient_r.so
rm %{buildroot}%{_libdir}/libmysqlservices.a
rm %{buildroot}%{_libdir}/pkgconfig/libmariadb.pc
rm %{buildroot}%{_libdir}/pkgconfig/mariadb.pc
rm %{buildroot}%{_datadir}/aclocal/mysql.m4
rm %{buildroot}%{_bindir}/mysql_config
rm %{buildroot}%{_bindir}/mariadb_config
rm %{buildroot}%{_mandir}/man1/mysql_config*
%endif

# when not building with bench sub-package
%if ! %{with bench}
rm -r %{buildroot}%{_datadir}/sql-bench
%endif

# when not building with backup sub-package
%if ! %{with backup}
rm %{buildroot}%{_mandir}/man1/mariabackup.1
rm %{buildroot}%{_mandir}/man1/mbstream.1
%endif

# when not building with test sub-package
%if ! %{with test}
rm %{buildroot}%{_bindir}/mysql_client_test
rm %{buildroot}%{_bindir}/mysqltest
rm %{buildroot}%{_mandir}/man1/mysql_client_test.1*
rm %{buildroot}%{_mandir}/man1/my_safe_process.1*
rm %{buildroot}%{_mandir}/man1/mysqltest.1*
rm %{buildroot}%{_mandir}/man1/mysql-stress-test.pl.1*
rm %{buildroot}%{_mandir}/man1/mysql-test-run.pl.1*
%endif

# when not building with wsrep
%if ! %{with wsrep}
rm %{buildroot}%{_mandir}/man1/wsrep_*.1*
rm %{buildroot}%{_datadir}/doc/%{name}/README-wsrep
rm %{buildroot}%{_datadir}/%{name}/wsrep_notify
%endif

# we are not building with embeded server
rm %{buildroot}%{_mandir}/man1/mysql_client_test_embedded.1
rm %{buildroot}%{_mandir}/man1/mysql_embedded.1
rm %{buildroot}%{_mandir}/man1/mysqltest_embedded.1

# when not building with embeded rocksdb
rm %{buildroot}%{_mandir}/man1/mysql_ldb.1*

# do not ship these
rm -r %{buildroot}%{_datadir}/%{name}/policy/apparmor/
rm -r %{buildroot}%{_datadir}/%{name}/policy/selinux/
rm  %{buildroot}%{_libdir}/%{name}/plugin/daemon_example.ini

# default folder for configs
mkdir %{buildroot}/%{_sysconfdir}/%{name}/my.cnf.d
# default data dir for mysqld
mkdir -p  %{buildroot}%{_localstatedir}/lib/%{name}/data
# default dir for mysql.sock
mkdir -p  %{buildroot}%{_localstatedir}/lib/mysql

# need to open up my.cnf and edit /etc/my.cnf.d to /QOpenSys/etc/mariadb/my.cnf.d
perl -p -i -e 's|/etc/my.cnf.d|%{_sysconfdir}/%{name}/my.cnf.d|g' %{buildroot}/%{_sysconfdir}/%{name}/my.cnf

# client package
%files
%defattr(-, qsys, *none)
%{_bindir}/msql2mysql
%{_bindir}/mysql
%{_bindir}/mysql_find_rows
%{_bindir}/mysql_plugin
%{_bindir}/mysql_waitpid
%{_bindir}/mysqlaccess
%{_bindir}/mysqladmin
%{_bindir}/mysqlbinlog
%{_bindir}/mysqlcheck
%{_bindir}/mysqldump
%{_bindir}/mysqlimport
%{_bindir}/mysqlshow
%{_bindir}/mysqlslap

%{_mandir}/man1/msql2mysql.1*
%{_mandir}/man1/mysql.1*
%{_mandir}/man1/mysql_find_rows.1*
%{_mandir}/man1/mysql_plugin.1*
%{_mandir}/man1/mysql_waitpid.1*
%{_mandir}/man1/mysqlaccess.1*
%{_mandir}/man1/mysqladmin.1*
%{_mandir}/man1/mysqlbinlog.1*
%{_mandir}/man1/mysqlcheck.1*
%{_mandir}/man1/mysqldump.1*
%{_mandir}/man1/mysqlimport.1*
%{_mandir}/man1/mysqlshow.1*
%{_mandir}/man1/mysqlslap.1*

%{_sysconfdir}/%{name}/client.cnf
%{_sysconfdir}/%{name}/mysql-clients.cnf
# should be in common package
%{_datadir}/%{name}/charsets


%files server
%defattr(-, qsys, *none)
%{_bindir}/aria_chk
%{_bindir}/aria_dump_log
%{_bindir}/aria_ftdump
%{_bindir}/aria_pack
%{_bindir}/aria_read_log
%{_bindir}/innochecksum
%{_bindir}/myisamchk
%{_bindir}/myisam_ftdump
%{_bindir}/myisamlog
%{_bindir}/myisampack
%{_bindir}/my_print_defaults
%{_bindir}/mysql_install_db
%{_bindir}/mysql_secure_installation
%{_bindir}/mysql_tzinfo_to_sql
%{_bindir}/mysqld_safe
%{_bindir}/mysqld_safe_helper
%{_bindir}/replace
%{_bindir}/resolve_stack_dump
%{_bindir}/resolveip

%if %{with wsrep}
%{_bindir}/wsrep_sst_common
%{_bindir}/wsrep_sst_mariabackup
%{_bindir}/wsrep_sst_mysqldump
%{_bindir}/wsrep_sst_rsync
%{_bindir}/wsrep_sst_rsync_wan
%endif

%{_bindir}/mysqld
%{_mandir}/man8/mysqld.8*

# server-utils
%{_bindir}/mysql_convert_table_format
%{_bindir}/mysql_fix_extensions
%{_bindir}/mysql_setpermission
%{_bindir}/mysql_upgrade
%{_bindir}/mysqld_multi
%{_bindir}/mysqldumpslow
%{_bindir}/mysqlhotcopy
%{_bindir}/mytop
%{_bindir}/perror

# plugins
%{_libdir}/%{name}/plugin/adt_null.so
%{_libdir}/%{name}/plugin/auth_0x0100.so
%{_libdir}/%{name}/plugin/auth_test_plugin.so
%{_libdir}/%{name}/plugin/caching_sha2_password.so
%{_libdir}/%{name}/plugin/dialog.so
%{_libdir}/%{name}/plugin/ha_test_sql_discovery.so
%{_libdir}/%{name}/plugin/locales.so
%{_libdir}/%{name}/plugin/metadata_lock_info.so
%{_libdir}/%{name}/plugin/mysql_clear_password.so
%{_libdir}/%{name}/plugin/qa_auth_client.so
%{_libdir}/%{name}/plugin/qa_auth_interface.so
%{_libdir}/%{name}/plugin/qa_auth_server.so
%{_libdir}/%{name}/plugin/query_cache_info.so
%{_libdir}/%{name}/plugin/sha256_password.so
%{_libdir}/%{name}/plugin/test_versioning.so


%{_mandir}/man1/aria_chk.1*
%{_mandir}/man1/aria_dump_log.1*
%{_mandir}/man1/aria_ftdump.1*
%{_mandir}/man1/aria_pack.1*
%{_mandir}/man1/aria_read_log.1*
%{_mandir}/man1/galera_new_cluster.1*
%{_mandir}/man1/galera_recovery.1*
%{_mandir}/man1/innochecksum.1*
%{_mandir}/man1/mariadb-service-convert.1*
%{_mandir}/man1/my_print_defaults.1*
%{_mandir}/man1/myisam_ftdump.1*
%{_mandir}/man1/myisamchk.1*
%{_mandir}/man1/myisamlog.1*
%{_mandir}/man1/myisampack.1*
%{_mandir}/man1/mysql.server.1*
%{_mandir}/man1/mysql_install_db.1*
%{_mandir}/man1/mysql_secure_installation.1*
%{_mandir}/man1/mysql_tzinfo_to_sql.1*
%{_mandir}/man1/mysqld_safe.1*
%{_mandir}/man1/mysqld_safe_helper.1*
%{_mandir}/man1/replace.1*
%{_mandir}/man1/resolve_stack_dump.1*
%{_mandir}/man1/resolveip.1*
%if %{with wsrep}
%{_mandir}/man1/wsrep_*.1*
%endif

# server-utils 
%{_mandir}/man1/mysql_convert_table_format.1*
%{_mandir}/man1/mysql_fix_extensions.1*
%{_mandir}/man1/mysql_setpermission.1*
%{_mandir}/man1/mysql_upgrade.1*
%{_mandir}/man1/mysqldumpslow.1*
%{_mandir}/man1/mysqld_multi.1*
%{_mandir}/man1/mysqlhotcopy.1*
%{_mandir}/man1/perror.1*

# errmsgs
%{_datadir}/%{name}/errmsg-utf8.txt
%{_datadir}/%{name}/czech/errmsg.sys
%{_datadir}/%{name}/danish/errmsg.sys
%{_datadir}/%{name}/dutch/errmsg.sys
%{_datadir}/%{name}/english/errmsg.sys
%{_datadir}/%{name}/estonian/errmsg.sys
%{_datadir}/%{name}/french/errmsg.sys
%{_datadir}/%{name}/german/errmsg.sys
%{_datadir}/%{name}/greek/errmsg.sys
%{_datadir}/%{name}/hindi/errmsg.sys
%{_datadir}/%{name}/hungarian/errmsg.sys
%{_datadir}/%{name}/italian/errmsg.sys
%{_datadir}/%{name}/japanese/errmsg.sys
%{_datadir}/%{name}/korean/errmsg.sys
%{_datadir}/%{name}/norwegian/errmsg.sys
%{_datadir}/%{name}/norwegian-ny/errmsg.sys
%{_datadir}/%{name}/polish/errmsg.sys
%{_datadir}/%{name}/portuguese/errmsg.sys
%{_datadir}/%{name}/romanian/errmsg.sys
%{_datadir}/%{name}/russian/errmsg.sys
%{_datadir}/%{name}/serbian/errmsg.sys
%{_datadir}/%{name}/slovak/errmsg.sys
%{_datadir}/%{name}/spanish/errmsg.sys
%{_datadir}/%{name}/swedish/errmsg.sys
%{_datadir}/%{name}/ukrainian/errmsg.sys

%{_datadir}/%{name}/fill_help_tables.sql
%{_datadir}/%{name}/install_spider.sql
%{_datadir}/%{name}/maria_add_gis_sp.sql
%{_datadir}/%{name}/maria_add_gis_sp_bootstrap.sql
%{_datadir}/%{name}/mysql_performance_tables.sql
%{_datadir}/%{name}/mysql_system_tables.sql
%{_datadir}/%{name}/mysql_system_tables_data.sql
%{_datadir}/%{name}/mysql_test_data_timezone.sql
%{_datadir}/%{name}/mysql_test_db.sql
%if %{with wsrep}
%{_datadir}/%{name}/wsrep.cnf
%{_datadir}/%{name}/wsrep_notify
%endif
%{_datadir}/%{name}/mysql-log-rotate

#figure where proper package for these
%{_datadir}/doc/%{name}/COPYING
%{_datadir}/doc/%{name}/THIRDPARTY
%{_datadir}/doc/%{name}/CREDITS
%{_datadir}/doc/%{name}/INSTALL-BINARY
%if %{with wsrep}
%{_datadir}/doc/%{name}/README-wsrep
%endif
%{_datadir}/doc/%{name}/README.md

# candidates for removal
%{_datadir}/%{name}/mysql.server
%{_datadir}/%{name}/mysqld_multi.server
%{_datadir}/%{name}/magic
%{_datadir}/%{name}/binary-configure

%{_sysconfdir}/%{name}/enable_encryption.preset
%{_sysconfdir}/%{name}/init.d/mysql
%{_sysconfdir}/%{name}/logrotate.d/mysql
%{_sysconfdir}/%{name}/server.cnf
%{_sysconfdir}/%{name}/my.cnf

%dir %{_sysconfdir}/%{name}/my.cnf.d
%{_localstatedir}/lib/%{name}/data
%dir %{_localstatedir}/lib/mysql

%if %{with devel}
%files devel
%defattr(-, qsys, *none)
%{_includedir}/%{name}/*
%{_libdir}/libmariadb.so
%{_libdir}/libmariadbclient.a
%{_libdir}/libmysqlclient.a
%{_libdir}/libmysqlclient.so
%{_libdir}/libmysqlclient_r.a
%{_libdir}/libmysqlclient_r.so
%{_libdir}/libmysqlservices.a

%{_libdir}/pkgconfig/libmariadb.pc
# Do we really need the following?
%{_datadir}/pkgconfig/mariadb.pc

%{_datadir}/aclocal/mysql.m4

%{_bindir}/mysql_config
%{_bindir}/mariadb_config
%{_mandir}/man1/mysql_config*
%endif

%if %{with backup}
%files backup
%{_bindir}/mariabackup
%{_bindir}/mbstream
%{_mandir}/man1/mariabackup.1*
%{_mandir}/man1/mbstream.1*
%endif

%if %{with test}
%files test
%defattr(-, qsys, *none)
%{_datadir}/mysql-test/*

%{_bindir}/mysql_client_test
%{_bindir}/mysqltest
%{_mandir}/man1/mysql_client_test.1*
%{_mandir}/man1/my_safe_process.1*
%{_mandir}/man1/mysqltest.1*
%{_mandir}/man1/mysql-stress-test.pl.1*
%{_mandir}/man1/mysql-test-run.pl.1*
%endif

%if %{with bench}
%files bench
%defattr(-, qsys, *none)
%{_datadir}/sql-bench/*
%endif

%if %{with db2iengine}
%files db2iengine
%defattr(-, qsys, *none)
%{_libdir}/%{name}/plugin/ha_ibmdb2i.so
%endif

%changelog
* Tue Aug 23 2022 Abdirahim Musse <abdirahim.musse@ibm.com> - 10.3.32
- Create and own default mysql.sock dir

* Wed May 18 2022 Abdirahim Musse <abdirahim.musse@ibm.com> - 10.3.32
- Build with latest CMake
- Resolve issues with dynamic plugins not working properly with CMake 3.16+
- Fix building mariadb in debug mode

* Mon Nov 29 2021 Abdirahim Musse <abdirahim.musse@ibm.com> - 10.3.32
- Update to 10.3.32
- Add version requires to sub-packages
- Update db2iengine version to 1.1.5

* Fri Oct 23 2020 Abdirahim Musse <abdirahim.musse@ibm.com> - 10.3.25
- Update to 10.3.25

* Thu Oct 22 2020 Abdirahim Musse <abdirahim.musse@ibm.com> - 10.3.14
- Conditionally build with db2iengine and split into sub-package

* Tue Oct 13 2020 Abdirahim Musse <abdirahim.musse@ibm.com> - 10.3.14
- Update source0 URL
- Update db2iengine version to 1.1.3

* Tue Jul 14 2020 Abdirahim Musse <abdirahim.musse@ibm.com> - 10.3.14
- Don't unnecessarily build plugins statically

* Tue Jul 07 2020 Abdirahim Musse <abdirahim.musse@ibm.com> - 10.3.14
- Build with ibmdb2i engine 1.1.2 for charset fix

* Mon Jun 08 2020 Kevin Adler <kadler@us.ibm.com> - 10.3.14
- Require libutil 0.8.1 for backtrace segfault fix

* Tue May 5 2020 - Abdirahim Musse <abdirahim.musse@ibm.com>
- Removed backtrace_symbols_fd patch because the function exists in libutil now

* Thu Feb 27 2020 - Abdirahim Musse <abdirahim.musse@ibm.com>
- Initial spec
